@@ -16,17 +16,16 @@ class LogFileNotOpen(Exception):
     pass
 
 
-class FileLoggerState:
-    def __init__(self) -> None:
-        self.file_handles: Dict[str, TextIO] = dict()
-        self.ts_str = datetime.now().strftime('%Y-%m-%d.%H.%M.%S')
-
-
 @logger
 class FileLogger(Logger):
+    class FileLoggerState:
+        def __init__(self) -> None:
+            self.file_handles: Dict[str, TextIO] = dict()
+            self.ts_str = datetime.now().strftime('%Y-%m-%d.%H.%M.%S')
+
+    _state: FileLoggerState = FileLoggerState()
     base_log_dir: str = './logs'
     retention_days: int = 10
-    _state: FileLoggerState = FileLoggerState()
 
     @property
     def log_dir(self) -> str:
@@ -49,7 +48,12 @@ class FileLogger(Logger):
             f = self._state.file_handles.get(msg.name)
             if not f or f.closed:
                 raise LogFileNotOpen(f'Log file is not open for {msg.name}')
-            f.write(msg.message)
+            template = '[{ts}] {sev} - {m}\n'
+            f.write(template.format(
+                sev=msg.severity.value,
+                ts=msg.timestamp,
+                m=msg.message
+            ))
 
     async def on_destroy(self) -> None:
         for f in self._state.file_handles.values():
